#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-utils
version:              1.12.0
visibility:           public
id:                   tamarin-prover-utils-1.12.0-9wSHJ9gg2aBHjJUU9X63kk
key:                  tamarin-prover-utils-1.12.0-9wSHJ9gg2aBHjJUU9X63kk
license:              LicenseRef-GPL
copyright:
    Benedikt Schmidt, Simon Meier, Cas Cremers, Jannik Dreier, Ralf Sasse, 2010-2023

maintainer:
    Cas Cremers <cremers@cispa.de>,
    Jannik Dreier <research@jannikdreier.net>,
    Ralf Sasse <ralf.sasse@gmail.com>

author:
    Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
    Simon Meier <simon.meier@inf.ethz.ch>,
    Jannik Dreier <research@jannikdreier.net>,
    Ralf Sasse <ralf.sasse@gmail.com>

homepage:             https://tamarin-prover.github.io/
synopsis:             Utility library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

category:             Theorem Provers
abi:                  d7ab5cd8e8ce50e60cb759237ff39440
exposed:              True
exposed-modules:
    Control.Basics Control.Monad.Bind Control.Monad.Disj
    Control.Monad.Fresh Control.Monad.Trans.FastFresh
    Control.Monad.Trans.PreciseFresh Data.Color Data.DAG.Simple
    Debug.Trace.EnvTracer Debug.Trace.Ignore Extension.Data.ByteString
    Extension.Data.Label Extension.Data.Monoid Extension.Prelude
    Logic.Connectives System.Timing Text.Dot Text.PrettyPrint.Class
    Text.PrettyPrint.Highlight Text.PrettyPrint.Html Text.Unicode
    Utils.Misc

hidden-modules:
    Control.Monad.Fresh.Class Control.Monad.Trans.Disj
    Control.Monad.Disj.Class

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tamarin-prover-utils-1.12.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tamarin-prover-utils-1.12.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tamarin-prover-utils-1.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-utils
hs-libraries:         HStamarin-prover-utils-1.12.0-9wSHJ9gg2aBHjJUU9X63kk
depends:
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg base-4.18.2.1
    base64-bytestring-1.2.1.0-6ahp7SfFZkd6mBBNURIRpE binary-0.8.9.1
    blaze-builder-0.4.4.1-6ZpLcXPUNy7ETCqm8SWojm bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.1 dlist-1.0-HIzSgqRZHiKsjIDkWs7Jg
    exceptions-0.10.7 fclabels-2.0.5.1-9Bt0R9U1ifE9weHKiYcMZt
    graphviz-2999.20.2.1-4wPJDjiBw8k9BZn3Sf68Wf
    list-t-1.0.5.7-2R7jLVaopLQHqGR2qHQBbn mtl-2.3.1 pretty-1.1.3.6
    safe-0.3.21-2iv11P1GTSG3w8ujmSn6bG
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-9ztCG0Q7snPDhcPoUMdZvi
    text-2.0.2 time-1.12.2 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-utils/html/tamarin-prover-utils.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-utils/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

